//
//  LLRegistrationController.h
//  LLRegistrationKit
//
//  Created by Damien DeVille on 3/18/14.
//  Copyright (c) 2014 Damien DeVille. All rights reserved.
//

#import <Foundation/Foundation.h>

extern NSString * const LLRegistrationApplicationVersionIdentifier;

typedef NS_ENUM(NSInteger, LLRegistrationState) {
	LLRegistrationStateDemo = 1,
	LLRegistrationStateExpired = 2,
	LLRegistrationStateVerified = 3,
};

@interface LLRegistrationController : NSObject

/*!
	\brief
	The current registration state
 */
@property (readonly, assign, nonatomic) LLRegistrationState state;

/*!
	\brief
	Present the registration window, application modally
 */
- (void)showApplicationModalRegistrationWindow;

/*!
	\brief
	Stop the modal session on the application and hide the registration window
 */
- (void)hideApplicationModalRegistrationWindow;

@end

@interface LLRegistrationController (Demo)

/*!
	\brief
	The number of remaining days in the demo
 */
@property (readonly, assign, nonatomic) NSInteger remainingDemoDays;

@end

@interface LLRegistrationController (Verification)

/*!
	\brief
	Load a saved license from persistent storage or `nil` if a license has never been saved
 */
- (NSString *)loadLicense;

/*!
	\brief
	Save a license to persistent storage
 */
- (void)saveLicense:(NSString *)license;

/*!
	\brief
	Verify a license, returning an error when the license is not valid
 */
- (BOOL)verifyLicense:(NSString *)license error:(NSError **)errorRef;

@end

@interface LLRegistrationController (Customization)

/*!
	\brief
	The URL to the store where to purchase the product
 */
@property (copy, nonatomic) NSURL *storeURL;

@end
