//
//  LLSpilloDataAccount.h
//  Spillo
//
//  Created by Damien DeVille on 10/16/16.
//  Copyright © 2016 Damien DeVille. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <CoreData/CoreData.h>

@class LLSpilloDataAccountPreferences;

typedef NS_ENUM(NSInteger, LLSpilloDataAccountType) {
	LLSpilloDataAccountTypePinboard = 1,
	LLSpilloDataAccountTypeLocal = 2,
};

@interface LLSpilloDataAccount : NSObject

/*!
	\brief
	The type of the account.
 */
@property (readonly, assign, nonatomic) LLSpilloDataAccountType type;
extern NSString * const LLSpilloDataAccountTypeKey;

/*!
	\brief
	The unique identifier for the account.
 */
@property (readonly, copy, nonatomic) NSString *identifier;
extern NSString * const LLSpilloDataAccountIdentifierKey;

/*!
	\brief
	The username of the currently authenticated user. Observable.
 */
@property (readonly, copy, nonatomic) NSString *username;
extern NSString * const LLSpilloDataAccountUsernameKey;

/*!
	\brief
	A localized description of the account that can be shown in the UI. Observable.
 */
@property (readonly, copy, nonatomic) NSString *localizedDescription;
extern NSString * const LLSpilloDataAccountLocalizedDescriptionKey;

/*!
	\brief
	The preferences associated with this account.
 */
@property (readonly, strong, nonatomic) LLSpilloDataAccountPreferences *preferences;
extern NSString * const LLSpilloDataAccountPreferencesKey;

/*!
	\brief
	YES if the user is authenticated, NO otherwise. Observable.
 */
@property (readonly, getter = isAuthenticated, assign, nonatomic) BOOL authenticated;
extern NSString * const LLSpilloDataAccountAuthenticatedKey;

/*!
	\brief
	YES if the account bookmark engine is currently loaded and its store mounted, NO otherwise. Observable.
 */
@property (readonly, getter = isLoaded, assign, nonatomic) BOOL loaded;
extern NSString * const LLSpilloDataAccountLoadedKey;

/*!
	\brief
	Returns YES if the account supports syncing, NO otherwise.
 */
@property (readonly, assign, nonatomic) BOOL supportsSyncing;
extern NSString * const LLSpilloDataAccountSupportsSyncingKey;

/*!
	\brief
	Returns YES if the account supports social features, NO otherwise.
 */
@property (readonly, assign, nonatomic) BOOL supportsSocialFeatures;
extern NSString * const LLSpilloDataAccountSupportsSocialFeaturesKey;

@end
