//
//  LLSpilloDataPinboardRefreshOperation.h
//  Spillo
//
//  Created by Damien DeVille on 4/20/14.
//  Copyright (c) 2014 Damien DeVille. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <CoreData/CoreData.h>

#import <LLCoreConcurrency/LLCoreConcurrency.h>

@class LLPinboardClient;

@interface LLSpilloDataPinboardRefreshOperation : LLConcurrentOperation

- (instancetype)initWithPinboardClient:(LLPinboardClient *)pinboardClient managedObjectContext:(NSManagedObjectContext *)managedObjectContext;

/*!
	\brief
	If set to YES, the refresh operation will only send the local changes.
 */
@property (assign, nonatomic) BOOL refreshLocalChangesOnly;

/*!
	\brief
	If set to YES, the refresh operation will refresh everything, even if the last update date hasn't changed.
 */
@property (assign, nonatomic) BOOL forceRefresh;

/*!
	\brief
	The last update date. Can be set before the operation is run and it will be updated when the operation completes.
 */
@property (strong, nonatomic) NSDate *lastUpdateDate;

/*!
	\brief
	This property is observable but might (and will!) be changed on different threads.
 */
@property (readonly, copy, atomic) NSString *status;

/*!
	\brief
	A completion provider that is populated before the operation finishes with either the result or an error by reference.
 */
@property (readonly, copy, atomic) NSNumber *(^completionProvider)(NSError **errorRef);

@end
