//
//  LLSpilloDataStoreCoordinator.h
//  Spillo
//
//  Created by Damien DeVille on 4/16/14.
//  Copyright (c) 2014 Damien DeVille. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <CoreData/CoreData.h>

@interface LLSpilloDataStoreCoordinator : NSObject

/*!
	\brief
	The location where to persist the stores.
 */
@property (copy, nonatomic) NSURL *storeContainerLocation;

/*!
	\brief
	Setup the coordinator, mounting the store and returning an error by reference if failing.
	
	\param errorRef
	A reference to an error.
	
	\return
	YES if the stores were correctly setup, NO otherwise.
 */
- (BOOL)setup:(NSError **)errorRef;

/*!
	\brief
	Teardown the coordinator, unmounting the store and returning an error by reference if failing.
 
	\param errorRef
	A reference to an error.
	
	\return
	YES if the stores were correctly torn down, NO otherwise.
 */
- (BOOL)teardown:(NSError **)errorRef;

@property (readonly, assign, getter = isSetup, nonatomic) BOOL setup;

@property (readonly, strong, nonatomic) NSPersistentStoreCoordinator *persistentStoreCoordinator;

@property (readonly, strong, nonatomic) NSManagedObjectContext *mainManagedObjectContext;
@property (readonly, strong, nonatomic) NSManagedObjectContext *workManagedObjectContext;

@end
